############################################################
# CG150.1 Headaches: Read in CODA data
############################################################

post.save.path <- "./Headaches thresholds - CODA data.Rda"
if (file.exists(post.save.path)) {
  load(post.save.path)
  cat("Using previously saved posterior statistics found in file",post.save.path,"\n")
} else {
  require(coda)
  system.time(
  dat.CODA <- mcmc.list(lapply(c("../WinBUGS/Coda1.txt",
                                   "../WinBUGS/Coda2.txt",
                                   "../WinBUGS/Coda3.txt"), 
                                 read.coda, index.file = "../WinBUGS/CodaIndex.txt"))
  )
  
  # Get indices of d_k (d) and d_ab (diff) in the CODA data
  vnames <- sub("(.*)\\[.*","\\1",varnames(dat.CODA))
  ind.d <- which(vnames=="d")
  ind.dd <- which(vnames=="diff")
  
  # Indices of some NB parameters
  ind.r <- which(vnames=="r")
  ind.utilMig <- which(vnames=="utilMig")
	
	# Get indices of deltas, mus, and tau in CODA data (for study level analysis)
  ind.delta <- which(vnames=="delta")
  ind.mu <- which(vnames=="mu")
  ind.tau <- which(vnames=="tau")
   
  # Posterior summary table for basic treatment parameters d_k
  post.summary <- summary(dat.CODA[,ind.d])
  
  # Posterior summary table for contrasts d_ab
  post.summarydd <- summary(dat.CODA[,ind.dd])
  
  # Posterior means of d_k
  post.mean <- post.summary$stat[,"Mean"]
  
  # Posterior means of d_ab
  post.meandd <- post.summarydd$stat[,"Mean"]
  
  # Posterior quantiles of d_ab
  post.q2.5dd <- post.summarydd$quant[,"2.5%"]
  post.meddd <- post.summarydd$quant[,"50%"]
  post.q97.5dd <- post.summarydd$quant[,"97.5%"]
  
  # Posterior covariance matrix of basic treatment parameters d_k
  # NOTE: cov(as.matrix(x)) is analagous to how coda::crosscorr calculates the
  # crosscorrelation matrix using cor(as.matrix(x))
  post.cov <- cov(as.matrix(dat.CODA[,ind.d]))
	
	# Calculate posterior covariance matrix of d, delta, mu (study level analysis)
  post.cov.full <- cov(as.matrix(dat.CODA[,c(ind.d, ind.delta, ind.mu)]))
  
  # Posterior expectations of some NB parameters
  post.r <- summary(dat.CODA[,ind.r])$stat["Mean"]
  post.utilMig <- summary(dat.CODA[,ind.utilMig])$stat["Mean"]
	
	# Posterior expectation of between studies variance
  post.sig2 <- mean(1/as.matrix(dat.CODA[,ind.tau]))
  
  # Save computed objects for next time
  save(post.summary, post.summarydd, 
       post.mean, post.meandd, 
       post.q2.5dd, post.meddd, post.q97.5dd, 
       post.cov, post.cov.full,
       post.r, post.utilMig,
			 post.sig2,
       file=post.save.path)
  
  # Unload dat.CODA to clear memory
  rm(dat.CODA)
}
