############################################################
# CG159 Social Anxiety: Read in CODA data
############################################################

# The CODA generated from WinBUGS is large, so if desired/available try to read
# the saved posterior statistics
post.save.path <- "./UI - CODA data.Rda"
if (file.exists(post.save.path)) {
  load(post.save.path)
  cat("Using previously saved posterior statistics found in file",post.save.path,"\n")
} else {
  
  require(coda)
  # Parallelise to reduce computation time
  require(parallelsugar) # Fix mclapply on Windows, from GitHub nathanvan/parallelsugar
  system.time(
    dat.CODA <- mcmc.list(mclapply(c("../WinBUGS/Coda1.txt",
                                     "../WinBUGS/Coda2.txt",
                                     "../WinBUGS/Coda3.txt"),
                                   read.coda, index.file = "../WinBUGS/CodaIndex.txt"))
  )
  
  # Get indices of d, mu, lor in the CODA data
  vnames <- sub("(.*)\\[.*","\\1",varnames(dat.CODA))
  ind.d <- which(vnames=="d")
  ind.mu <- which(vnames=="mu")
  ind.lor <- which(vnames=="lor")
  
  # Posterior summary table for basic treatment parameters d_k
  d.summary <- summary(dat.CODA[,ind.d])
  
  # Posterior means of d_k
  d.mean <- d.summary$stat[,"Mean"]
  
  # Posterior summary table for study baseline parameters mu
  mu.summary <- summary(dat.CODA[,ind.mu])
  
  # Posterior means of mu
  mu.mean <- mu.summary$stat[,"Mean"]

  # Posterior summary table for contrasts
  dd.summary <- summary(dat.CODA[,ind.lor])
  
  # Posterior means of contrasts
  dd.mean <- dd.summary$stat[,"Mean"]
  
  # Posterior covariance matrix of basic treatment parameters d_k
  # NOTE: cov(as.matrix(x)) is analagous to how coda::crosscorr calculates the
  # crosscorrelation matrix using cor(as.matrix(x))
  post.cov <- cov(as.matrix(dat.CODA[,ind.d]))
  
  # Save computed objects for next time
  save(d.summary, d.mean, 
       mu.summary, mu.mean,
       dd.summary, dd.mean,
       post.cov, 
       file=post.save.path)
  
  # Unload dat.CODA to clear memory
  rm(dat.CODA)
}