############################################################
# NG25 Tocolytics EGA : Read in CODA data
############################################################

# The CODA generated from WinBUGS is huge, so if desired/available try to read
# the saved posterior statistics
post.save.path <- "./Tocolytics - CODA data.Rda"
if (file.exists(post.save.path)) {
  load(post.save.path)
  cat("Using previously saved posterior statistics found in file",post.save.path,"\n")
} else {
  
  require(coda)
  # Parallelise to reduce computation time
  require(parallelsugar) # Fix mclapply on Windows, from GitHub nathanvan/parallelsugar
  system.time(
    dat.CODA <- mcmc.list(mclapply(c("../WinBUGS/Coda1.txt",
                                     "../WinBUGS/Coda2.txt",
                                     "../WinBUGS/Coda3.txt"),
                                   read.coda, index.file = "../WinBUGS/CodaIndex.txt"))
  )
  
  # Get indices of d, sd, diff in the CODA data
  vnames <- sub("(.*)\\[.*","\\1",varnames(dat.CODA))
  ind.d <- which(vnames=="d")
  ind.mu <- which(vnames=="mu")
  ind.sd <- which(vnames=="sd")
  ind.diff <- which(vnames=="diff")
  ind.delta <- which(vnames=="delta")
  
  # Posterior summary table for basic treatment parameters d_k
  post.summary <- summary(dat.CODA[,ind.d])
  
  # Posterior means of d_k
  post.mean <- post.summary$stat[,"Mean"]
  
  # Posterior summary table for between studies sd and variance
  sd.summary <- summary(dat.CODA[,ind.sd])
  tausq.summary <- summary(as.mcmc(as.matrix(dat.CODA[,ind.sd])^2))
  
  # Posterior means of sd and tausq
  sd.mean <- sd.summary$stat["Mean"]
  tausq.mean <- tausq.summary$stat["Mean"]
  
  # Posterior summary table for contrasts
  dd.summary <- summary(dat.CODA[,ind.diff])
  
  # Posterior means of contrasts
  dd.mean <- dd.summary$stat[,"Mean"]
  
  # Posterior covariance matrix of basic treatment parameters d_k
  # NOTE: cov(as.matrix(x)) is analagous to how coda::crosscorr calculates the
  # crosscorrelation matrix using cor(as.matrix(x))
  post.cov <- cov(as.matrix(dat.CODA[,ind.d]))
  
  # Posterior covariance matrix of d, delta, and mu
  post.cov.ddelta <- cov(as.matrix(dat.CODA[,c(ind.d,ind.delta,ind.mu)]))
  
  # Save computed objects for next time
  save(post.summary, post.mean, 
       sd.summary, tausq.summary,
       sd.mean, tausq.mean,
       dd.summary, dd.mean,
       post.cov, post.cov.ddelta,
       file=post.save.path)
  
  # Unload dat.CODA to clear memory
  rm(dat.CODA)
}