#######################################################
# FUNCTION: d_i2ab                     
# Get treatment codes of the contrast d_ab for element 
# d_i in the contrast vector.
#
# ARGUMENTS:
#  i    = Indices of contrasts in contrast vector
#  K    = Total number of treatments
#
# AUTHOR: David M. Phillippo, 
#         University of Bristol
#######################################################

d_i2ab <- function(i,K){
  if(any(i>K*(K-1)/2)) {
    stop("Index i is greater than the total number of contrasts K(K-1)/2")
  }
  
  # Generate "triangular" numbers
  tri <- lower.tri(matrix(nrow=K-1,ncol=K-1),diag=T) %*% (K-1):1
  
  # Get a,b
  a <- b <- rep(NA,length(i))
  for (j in 1:length(i)){
    a[j] <- which(i[j] <= tri)[1]
    b[j] <- i[j] - c(0,tri)[a[j]] + a[j]
  }
  
  return(list(a=a,b=b))
}
